@@ -15,23 +15,6 @@
 
     Contact: code@inmanta.com
 """
-import warnings
-
-"""
-About the use of @parametrize_any and @slowtest:
-
-For parametrized tests:
-- if the test is fast and tests different things for each parameter, use @parametrize
-- if the parameters only slightly increase the coverage of the test (some different exception path,...), use @parametrize_any.
-- if a test is slow, use @parametrize_any
-
-The @slowtest annotation is usually added on test periodically, when the test suite becomes too slow.
-We analyze performance and place the @slowtest in the best places.
-It is often harder to correctly judge what is slow up front, so we do it in bulk when we have all the (historical) data.
-This also allows test to run a few hundred times before being marked as slow.
-"""
-
-
 import asyncio
 import concurrent
 import csv
@@ -51,7 +34,7 @@ import tempfile
 import time
 import traceback
 import uuid
-from typing import AsyncIterator, Awaitable, Callable, Dict, List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple
 
 import asyncpg
 import pkg_resources
@@ -64,11 +47,9 @@ from pyformance.registry import MetricsRegistry
 from tornado import netutil
 from tornado.platform.asyncio import AnyThreadEventLoopPolicy
 
-import inmanta
 import inmanta.agent
 import inmanta.app
 import inmanta.compiler as compiler
-import inmanta.compiler.config
 import inmanta.main
 from inmanta import config, const, data, loader, protocol, resources
 from inmanta.agent import handler
@@ -77,7 +58,6 @@ from inmanta.ast import CompilerException
 from inmanta.data.schema import SCHEMA_VERSION_TABLE
 from inmanta.export import cfg_env, unknown_parameters
 from inmanta.module import Project
-from inmanta.parser.plyInmantaParser import cache_manager
 from inmanta.postgresproc import PostgresProc
 from inmanta.protocol import VersionMatch
 from inmanta.server import SLICE_AGENT_MANAGER, SLICE_COMPILER
@@ -85,86 +65,17 @@ from inmanta.server.bootloader import InmantaBootloader
 from inmanta.server.protocol import SliceStartupException
 from inmanta.server.services.compilerservice import CompilerService, CompileRun
 from inmanta.types import JsonType
-from inmanta.warnings import WarningsManager
 
-# Import test modules differently when conftest is put into the inmanta_tests packages
-PYTEST_PLUGIN_MODE: bool = __file__ and os.path.dirname(__file__).split("/")[-1] == "inmanta_tests"
-if PYTEST_PLUGIN_MODE:
+# Import the utils module differently when conftest is put into the inmanta_tests packages
+if __file__ and os.path.dirname(__file__).split("/")[-1] == "inmanta_tests":
     from inmanta_tests import utils  # noqa: F401
-    from inmanta_tests.db.common import PGRestore  # noqa: F401
 else:
     import utils
-    from db.common import PGRestore
 
 logger = logging.getLogger(__name__)
 
 TABLES_TO_KEEP = [x.table_name() for x in data._classes]
 
-# Save the cwd as early as possible to prevent that it gets overridden by another fixture
-# before it's saved.
-initial_cwd = os.getcwd()
-
-
-def _pytest_configure_plugin_mode(config: "pytest.Config") -> None:
-    # register custom markers
-    config.addinivalue_line(
-        "markers",
-        "slowtest",
-    )
-    config.addinivalue_line(
-        "markers",
-        "parametrize_any: only execute one of the parameterized cases when in fast mode (see documentation in conftest.py)",
-    )
-    config.addinivalue_line(
-        "markers",
-        "db_restore_dump(dump): mark the db dump to restore. To be used in conjunction with the `migrate_db_from` fixture.",
-    )
-
-
-def pytest_configure(config: "pytest.Config") -> None:
-    if PYTEST_PLUGIN_MODE:
-        _pytest_configure_plugin_mode(config)
-
-
-def pytest_addoption(parser):
-    parser.addoption(
-        "--fast",
-        action="store_true",
-        help="Don't run all test, but a representative set",
-    )
-
-
-@pytest.hookimpl(tryfirst=True)
-def pytest_generate_tests(metafunc: "pytest.Metafunc") -> None:
-    """
-    For each test marked as parametrize_any run it either as
-    1. if not in fast mode: as if annotated with @parametrize
-    2. if in fast mode: with only one parameter combination, chosen randomly
-    """
-
-    is_fast = metafunc.config.getoption("fast")
-    for marker in metafunc.definition.iter_markers(name="parametrize_any"):
-        variations = len(marker.args[1])
-        if not is_fast or variations < 2:
-            metafunc.definition.add_marker(pytest.mark.parametrize(*marker.args))
-        else:
-            # select one random item
-            args = list(marker.args)
-            selected = args[1][random.randrange(0, variations)]
-            args[1] = [selected]
-            metafunc.definition.add_marker(pytest.mark.parametrize(*args))
-
-
-def pytest_runtest_setup(item: "pytest.Item"):
-    """
-    When in fast mode, skip test marked as slow
-    """
-    is_fast = item.config.getoption("fast")
-    if not is_fast:
-        return
-    if any(True for mark in item.iter_markers(name="slowtest")):
-        pytest.skip("Skipping slow tests")
-
 
 # Database
 @pytest.fixture
@@ -174,7 +85,7 @@ def postgres_proc(unused_tcp_port_factory):
     proc.stop()
 
 
-@pytest.fixture(scope="session")
+@pytest.fixture(scope="session", autouse=True)
 def postgres_db(postgresql_proc):
     yield postgresql_proc
 
@@ -277,19 +188,6 @@ async def postgress_get_custom_types(postgresql_client):
 async def do_clean_hard(postgresql_client):
     assert not postgresql_client.is_in_transaction()
     await postgresql_client.reload_schema_state()
-    # query taken from : https://database.guide/3-ways-to-list-all-functions-in-postgresql/
-    functions_query = """
-SELECT routine_name
-FROM  information_schema.routines
-WHERE routine_type = 'FUNCTION'
-AND routine_schema = 'public';
-    """
-    functions_in_db = await postgresql_client.fetch(functions_query)
-    function_names = [x["routine_name"] for x in functions_in_db]
-    if function_names:
-        drop_query = "DROP FUNCTION if exists %s " % ", ".join(function_names)
-        await postgresql_client.execute(drop_query)
-
     tables_in_db = await postgresql_client.fetch("SELECT table_name FROM information_schema.tables WHERE table_schema='public'")
     table_names = ["public." + x["table_name"] for x in tables_in_db]
     if table_names:
@@ -300,12 +198,7 @@ AND routine_schema = 'public';
     if type_names:
         drop_query = "DROP TYPE %s" % ", ".join(type_names)
         await postgresql_client.execute(drop_query)
-    logger.info(
-        "Performed Hard Clean with tables: %s  types: %s  functions: %s",
-        ",".join(table_names),
-        ",".join(type_names),
-        ",".join(function_names),
-    )
+    logger.info("Performed Hard Clean with tables: %s  types: %s", ",".join(table_names), ",".join(type_names))
 
 
 @pytest.fixture(scope="function")
@@ -396,7 +289,6 @@ async def clean_reset(create_db, clean_db):
     config.Config._reset()
     reset_all_objects()
     loader.unload_inmanta_plugins()
-    cache_manager.detach_from_project()
 
 
 def reset_all_objects():
@@ -415,8 +307,9 @@ def restore_cwd():
     """
     Restore the current working directory after search test.
     """
+    cwd = os.getcwd()
     yield
-    os.chdir(initial_cwd)
+    os.chdir(cwd)
 
 
 @pytest.fixture(scope="function")
@@ -456,7 +349,7 @@ def inmanta_config():
 
 
 @pytest.fixture
-def server_pre_start(server_config):
+def server_pre_start():
     """This fixture is called by the server. Override this fixture to influence server config"""
 
 
@@ -580,31 +473,33 @@ def log_state_tcp_ports(request, log_file):
 async def server_config(event_loop, inmanta_config, postgres_db, database_name, clean_reset, unused_tcp_port_factory):
     reset_metrics()
 
-    with tempfile.TemporaryDirectory() as state_dir:
-        port = str(unused_tcp_port_factory())
+    state_dir = tempfile.mkdtemp()
 
-        config.Config.set("database", "name", database_name)
-        config.Config.set("database", "host", "localhost")
-        config.Config.set("database", "port", str(postgres_db.port))
-        config.Config.set("database", "connection_timeout", str(3))
-        config.Config.set("config", "state-dir", state_dir)
-        config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
-        config.Config.set("agent_rest_transport", "port", port)
-        config.Config.set("compiler_rest_transport", "port", port)
-        config.Config.set("client_rest_transport", "port", port)
-        config.Config.set("cmdline_rest_transport", "port", port)
-        config.Config.set("server", "bind-port", port)
-        config.Config.set("server", "bind-address", "127.0.0.1")
-        config.Config.set("server", "agent-process-purge-interval", "0")
-        config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
-        config.Config.set("server", "agent-timeout", "2")
-        config.Config.set("server", "auto-recompile-wait", "0")
-        config.Config.set("agent", "agent-repair-interval", "0")
-        yield config
+    port = str(unused_tcp_port_factory())
+
+    config.Config.set("database", "name", database_name)
+    config.Config.set("database", "host", "localhost")
+    config.Config.set("database", "port", str(postgres_db.port))
+    config.Config.set("database", "connection_timeout", str(3))
+    config.Config.set("config", "state-dir", state_dir)
+    config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
+    config.Config.set("agent_rest_transport", "port", port)
+    config.Config.set("compiler_rest_transport", "port", port)
+    config.Config.set("client_rest_transport", "port", port)
+    config.Config.set("cmdline_rest_transport", "port", port)
+    config.Config.set("server", "bind-port", port)
+    config.Config.set("server", "bind-address", "127.0.0.1")
+    config.Config.set("server", "agent-process-purge-interval", "0")
+    config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
+    config.Config.set("server", "agent-timeout", "2")
+    config.Config.set("server", "auto-recompile-wait", "0")
+    config.Config.set("agent", "agent-repair-interval", "0")
+    yield config
+    shutil.rmtree(state_dir)
 
 
 @pytest.fixture(scope="function")
-async def server(server_pre_start):
+async def server(server_pre_start, server_config):
     """
     :param event_loop: explicitly include event_loop to make sure event loop started before and closed after this fixture.
     May not be required
@@ -646,72 +541,75 @@ async def server_multi(
     :param event_loop: explicitly include event_loop to make sure event loop started before and closed after this fixture.
     May not be required
     """
-    with tempfile.TemporaryDirectory() as state_dir:
-        ssl, auth, ca = request.param
+    state_dir = tempfile.mkdtemp()
 
-        path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
+    ssl, auth, ca = request.param
 
-        if auth:
-            config.Config.set("server", "auth", "true")
+    path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
 
-        for x, ct in [
-            ("server", None),
-            ("agent_rest_transport", ["agent"]),
-            ("compiler_rest_transport", ["compiler"]),
-            ("client_rest_transport", ["api", "compiler"]),
-            ("cmdline_rest_transport", ["api"]),
-        ]:
-            if ssl and not ca:
-                config.Config.set(x, "ssl_cert_file", os.path.join(path, "server.crt"))
-                config.Config.set(x, "ssl_key_file", os.path.join(path, "server.open.key"))
-                config.Config.set(x, "ssl_ca_cert_file", os.path.join(path, "server.crt"))
-                config.Config.set(x, "ssl", "True")
-            if ssl and ca:
-                capath = os.path.join(path, "ca", "enduser-certs")
+    if auth:
+        config.Config.set("server", "auth", "true")
 
-                config.Config.set(x, "ssl_cert_file", os.path.join(capath, "server.crt"))
-                config.Config.set(x, "ssl_key_file", os.path.join(capath, "server.key.open"))
-                config.Config.set(x, "ssl_ca_cert_file", os.path.join(capath, "server.chain"))
-                config.Config.set(x, "ssl", "True")
-            if auth and ct is not None:
-                token = protocol.encode_token(ct)
-                config.Config.set(x, "token", token)
+    for x, ct in [
+        ("server", None),
+        ("agent_rest_transport", ["agent"]),
+        ("compiler_rest_transport", ["compiler"]),
+        ("client_rest_transport", ["api", "compiler"]),
+        ("cmdline_rest_transport", ["api"]),
+    ]:
+        if ssl and not ca:
+            config.Config.set(x, "ssl_cert_file", os.path.join(path, "server.crt"))
+            config.Config.set(x, "ssl_key_file", os.path.join(path, "server.open.key"))
+            config.Config.set(x, "ssl_ca_cert_file", os.path.join(path, "server.crt"))
+            config.Config.set(x, "ssl", "True")
+        if ssl and ca:
+            capath = os.path.join(path, "ca", "enduser-certs")
 
-        port = str(unused_tcp_port_factory())
-        config.Config.set("database", "name", database_name)
-        config.Config.set("database", "host", "localhost")
-        config.Config.set("database", "port", str(postgres_db.port))
-        config.Config.set("database", "connection_timeout", str(3))
-        config.Config.set("config", "state-dir", state_dir)
-        config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
-        config.Config.set("agent_rest_transport", "port", port)
-        config.Config.set("compiler_rest_transport", "port", port)
-        config.Config.set("client_rest_transport", "port", port)
-        config.Config.set("cmdline_rest_transport", "port", port)
-        config.Config.set("server", "bind-port", port)
-        config.Config.set("server", "bind-address", "127.0.0.1")
-        config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
-        config.Config.set("server", "agent-timeout", "2")
-        config.Config.set("agent", "agent-repair-interval", "0")
-        config.Config.set("server", "auto-recompile-wait", "0")
+            config.Config.set(x, "ssl_cert_file", os.path.join(capath, "server.crt"))
+            config.Config.set(x, "ssl_key_file", os.path.join(capath, "server.key.open"))
+            config.Config.set(x, "ssl_ca_cert_file", os.path.join(capath, "server.chain"))
+            config.Config.set(x, "ssl", "True")
+        if auth and ct is not None:
+            token = protocol.encode_token(ct)
+            config.Config.set(x, "token", token)
 
-        ibl = InmantaBootloader()
+    port = str(unused_tcp_port_factory())
+    config.Config.set("database", "name", database_name)
+    config.Config.set("database", "host", "localhost")
+    config.Config.set("database", "port", str(postgres_db.port))
+    config.Config.set("database", "connection_timeout", str(3))
+    config.Config.set("config", "state-dir", state_dir)
+    config.Config.set("config", "log-dir", os.path.join(state_dir, "logs"))
+    config.Config.set("agent_rest_transport", "port", port)
+    config.Config.set("compiler_rest_transport", "port", port)
+    config.Config.set("client_rest_transport", "port", port)
+    config.Config.set("cmdline_rest_transport", "port", port)
+    config.Config.set("server", "bind-port", port)
+    config.Config.set("server", "bind-address", "127.0.0.1")
+    config.Config.set("config", "executable", os.path.abspath(inmanta.app.__file__))
+    config.Config.set("server", "agent-timeout", "2")
+    config.Config.set("agent", "agent-repair-interval", "0")
+    config.Config.set("server", "auto-recompile-wait", "0")
 
-        try:
-            await ibl.start()
-        except SliceStartupException as e:
-            port = config.Config.get("server", "bind-port")
-            output = subprocess.check_output(["ss", "-antp"])
-            output = output.decode("utf-8")
-            logger.debug(f"Port: {port}")
-            logger.debug(f"Port usage: \n {output}")
-            raise e
+    ibl = InmantaBootloader()
 
-        yield ibl.restserver
-        try:
-            await asyncio.wait_for(ibl.stop(), 15)
-        except concurrent.futures.TimeoutError:
-            logger.exception("Timeout during stop of the server in teardown")
+    try:
+        await ibl.start()
+    except SliceStartupException as e:
+        port = config.Config.get("server", "bind-port")
+        output = subprocess.check_output(["ss", "-antp"])
+        output = output.decode("utf-8")
+        logger.debug(f"Port: {port}")
+        logger.debug(f"Port usage: \n {output}")
+        raise e
+
+    yield ibl.restserver
+    try:
+        await asyncio.wait_for(ibl.stop(), 15)
+    except concurrent.futures.TimeoutError:
+        logger.exception("Timeout during stop of the server in teardown")
+
+    shutil.rmtree(state_dir)
 
 
 @pytest.fixture(scope="function")
@@ -739,23 +637,29 @@ def clienthelper(client, environment):
 
 @pytest.fixture(scope="function", autouse=True)
 def capture_warnings():
-    # Ensure that the test suite uses the same config for warnings as the default config used by the CLI tools.
     logging.captureWarnings(True)
-    cmd_parser = inmanta.app.cmd_parser()
-    WarningsManager.apply_config({"default": cmd_parser.get_default("warnings")})
     yield
-    warnings.resetwarnings()
     logging.captureWarnings(False)
 
 
-async def create_environment(client, use_custom_env_settings: bool) -> str:
+@pytest.fixture(scope="function")
+async def environment(client, server, environment_default):
+    """
+    Create a project and environment, with auto_deploy turned off. This fixture returns the uuid of the environment
     """
-    Create a project (env-test) and an environment (dev).
 
-    :param client: The client that should be used to create the project and environment.
-    :param use_custom_env_settings: True iff the auto_deploy features is disabled and the
-                                    agent trigger method is set to push_full_deploy.
-    :return: The uuid of the newly created environment as a string.
+    env = await data.Environment.get_by_id(uuid.UUID(environment_default))
+    await env.set(data.AUTO_DEPLOY, False)
+    await env.set(data.PUSH_ON_AUTO_DEPLOY, False)
+    await env.set(data.AGENT_TRIGGER_METHOD_ON_AUTO_DEPLOY, const.AgentTriggerMethod.push_full_deploy)
+
+    yield environment_default
+
+
+@pytest.fixture(scope="function")
+async def environment_default(client, server):
+    """
+    Create a project and environment. This fixture returns the uuid of the environment
     """
     result = await client.create_project("env-test")
     assert result.code == 200
@@ -766,42 +670,23 @@ async def create_environment(client, use_custom_env_settings: bool) -> str:
 
     cfg_env.set(env_id)
 
-    if use_custom_env_settings:
-        env_obj = await data.Environment.get_by_id(uuid.UUID(env_id))
-        await env_obj.set(data.AUTO_DEPLOY, False)
-        await env_obj.set(data.PUSH_ON_AUTO_DEPLOY, False)
-        await env_obj.set(data.AGENT_TRIGGER_METHOD_ON_AUTO_DEPLOY, const.AgentTriggerMethod.push_full_deploy)
-
-    return env_id
-
-
-@pytest.fixture(scope="function")
-async def environment(client, server) -> AsyncIterator[str]:
-    """
-    Create a project and environment, with auto_deploy turned off and push_full_deploy set to push_full_deploy.
-    This fixture returns the uuid of the environment.
-    """
-    env_id = await create_environment(client, use_custom_env_settings=True)
     yield env_id
 
 
 @pytest.fixture(scope="function")
-async def environment_default(client, server) -> AsyncIterator[str]:
+async def environment_multi(client_multi, server_multi):
     """
-    Create a project and environment with default environment settings.
-    This fixture returns the uuid of the environment.
+    Create a project and environment. This fixture returns the uuid of the environment
     """
-    env_id = await create_environment(client, use_custom_env_settings=False)
-    yield env_id
+    result = await client_multi.create_project("env-test")
+    assert result.code == 200
+    project_id = result.result["project"]["id"]
 
+    result = await client_multi.create_environment(project_id=project_id, name="dev")
+    env_id = result.result["environment"]["id"]
+
+    cfg_env.set(env_id)
 
-@pytest.fixture(scope="function")
-async def environment_multi(client_multi, server_multi) -> AsyncIterator[str]:
-    """
-    Create a project and environment, with auto_deploy turned off and the agent trigger method set to push_full_deploy.
-    This fixture returns the uuid of the environment.
-    """
-    env_id = await create_environment(client_multi, use_custom_env_settings=True)
     yield env_id
 
 
@@ -858,12 +743,15 @@ class SnippetCompilationTest(KeepOnFail):
         self.repo = "https://github.com/inmanta/"
         self.env = tempfile.mkdtemp()
         config.Config.load_config()
+        self.cwd = os.getcwd()
         self.keep_shared = False
 
     def tearDownClass(self):
         if not self.keep_shared:
             shutil.rmtree(self.libs)
             shutil.rmtree(self.env)
+        # reset cwd
+        os.chdir(self.cwd)
 
     def setup_func(self, module_dir):
         # init project
@@ -983,9 +871,7 @@ def snippetcompiler_global():
 
 
 @pytest.fixture(scope="function")
-def snippetcompiler(inmanta_config, snippetcompiler_global, modules_dir):
-    # Test with compiler cache enabled
-    compiler.config.feature_compiler_cache.set("True")
+def snippetcompiler(snippetcompiler_global, modules_dir):
     snippetcompiler_global.setup_func(modules_dir)
     yield snippetcompiler_global
     snippetcompiler_global.tear_down_func()
@@ -1103,40 +989,3 @@ async def mocked_compiler_service_block(server, monkeypatch):
     monkey_patch_compiler_service(monkeypatch, server, True, runner_queue)
 
     yield runner_queue
-
-
-@pytest.fixture
-async def migrate_db_from(
-    request: pytest.FixtureRequest, hard_clean_db, hard_clean_db_post, postgresql_client: asyncpg.Connection, server_pre_start
-) -> AsyncIterator[Callable[[], Awaitable[None]]]:
-    """
-    Restores a db dump and yields a function that starts the server and migrates the database schema to the latest version.
-
-    :param db_restore_dump: The db version dump file to restore (set via `@pytest.mark.db_restore_dump(<file>)`.
-    """
-    marker: Optional[pytest.mark.Mark] = request.node.get_closest_marker("db_restore_dump")
-    if marker is None or len(marker.args) != 1:
-        raise ValueError("Please set the db version to restore using `@pytest.mark.db_restore_dump(<file>)`")
-    # restore old version
-    with open(marker.args[0], "r") as fh:
-        await PGRestore(fh.readlines(), postgresql_client).run()
-
-    bootloader: InmantaBootloader = InmantaBootloader()
-
-    async def migrate() -> None:
-        # start boatloader, triggering db migration
-        await bootloader.start()
-        # inform asyncpg of any type changes so it knows to refresh its caches
-        await postgresql_client.reload_schema_state()
-
-    yield migrate
-
-    await bootloader.stop()
-
-
-@pytest.fixture(scope="function", autouse=True)
-async def set_running_tests():
-    """
-    Ensure the RUNNING_TESTS variable is True when running tests
-    """
-    inmanta.RUNNING_TESTS = True
