@@ -16,34 +16,29 @@
     Contact: code@inmanta.com
 """
 import asyncio
-import datetime
+import inspect
 import json
 import logging
+import time
 import uuid
-from typing import Any, Awaitable, Callable, Dict, List, Union
+from typing import Any, Dict
 
-import pytest
-from pkg_resources import parse_version
-from pydantic.tools import lru_cache
-
-from _pytest.mark import MarkDecorator
-from inmanta import data, util
+from inmanta import data
 from inmanta.protocol import Client
-from inmanta.server.bootloader import InmantaBootloader
-from inmanta.server.extensions import ProductMetadata
 from inmanta.util import get_compiler_version
 
 
-async def retry_limited(
-    fun: Union[Callable[..., bool], Callable[..., Awaitable[bool]]],
-    timeout: float,
-    interval: float = 0.1,
-    *args: object,
-    **kwargs: object,
-) -> None:
-    try:
-        await util.retry_limited(fun, timeout, interval, *args, **kwargs)
-    except asyncio.TimeoutError:
+async def retry_limited(fun, timeout, *args, **kwargs):
+    async def fun_wrapper():
+        if inspect.iscoroutinefunction(fun):
+            return await fun(*args, **kwargs)
+        else:
+            return fun(*args, **kwargs)
+
+    start = time.time()
+    while time.time() - start < timeout and not (await fun_wrapper()):
+        await asyncio.sleep(0.1)
+    if not (await fun_wrapper()):
         raise AssertionError("Bounded wait failed")
 
 
@@ -205,20 +200,6 @@ class LogSequence(object):
         self.assert_not("", logging.ERROR, "")
 
 
-NOISY_LOGGERS = [
-    "inmanta.config",  # Option deprecations
-    "inmanta.util",  # cancel background tasks
-]
-
-
-def assert_no_warning(caplog, loggers_to_allow: List[str] = NOISY_LOGGERS):
-    """
-    Assert there are no warning, except from the list of loggers to allow
-    """
-    for record in caplog.records:
-        assert record.levelname != "WARNING" or (record.name in loggers_to_allow)
-
-
 def configure(unused_tcp_port, database_name, database_port):
     import inmanta.agent.config  # noqa: F401
     import inmanta.server.config  # noqa: F401
@@ -316,27 +297,3 @@ def get_resource(version: int, key: str = "key1", agent: str = "agent1", value:
         "purged": False,
         "requires": [],
     }
-
-
-@lru_cache(1)
-def get_product_meta_data() -> ProductMetadata:
-    """Get the produce meta-data"""
-    bootloader = InmantaBootloader()
-    context = bootloader.load_slices()
-    return context.get_product_metadata()
-
-
-def product_version_lower_or_equal_than(version: str) -> bool:
-    return parse_version(get_product_meta_data().version) <= parse_version(version)
-
-
-def mark_only_for_version_higher_than(version: str) -> "MarkDecorator":
-    current = get_product_meta_data().version
-    return pytest.mark.skipif(
-        product_version_lower_or_equal_than(version),
-        reason=f"This test is only intended for version larger than {version} currently at {current}",
-    )
-
-
-def parse_datetime_to_utc(time: str) -> datetime.datetime:
-    return datetime.datetime.strptime(time, "%Y-%m-%dT%H:%M:%S.%f").replace(tzinfo=datetime.timezone.utc)
